tasks

package module
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 8, 2025 License: Apache-2.0 Imports: 6 Imported by: 0

README

tasks

Mage task support methods

Documentation

Overview

Package tasks is used by Magefile scripts to tag and version applications.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Release

func Release() error

Release generates a version number based on the current timestamps, tags the repo, and pushes.

Types

type Info

type Info struct {
	Repo        bool
	Uncommitted bool
	Tag         string
	Branch      string
	Commit      string
	ShortCommit string
	Time        string
}

Info provides an information object defining the current build environment, either using the current repo (preferred) or Google Cloud build environment variables.

func Now

func Now() Info

Now generates an information object from the current environment.

func (Info) LDFlags

func (i Info) LDFlags() string

LDFlags generates the flags to send to the linker to add build meta data

func (Info) Version

func (i Info) Version() string

Version takes the info object and attempts to determine what a version string might look like.

Jump to