Documentation
¶
Overview ¶
Package tasks is used by Magefile scripts to tag and version applications.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Info ¶
type Info struct {
Repo bool
Uncommitted bool
Tag string
Branch string
Commit string
ShortCommit string
Time string
}
Info provides an information object defining the current build environment, either using the current repo (preferred) or Google Cloud build environment variables.
Click to show internal directories.
Click to hide internal directories.